pitchtools.list_named_chromatic_pitch_carriers_in_expr_sorted_by_numbered_chromatic_pitch_class
===============================================================================================

.. autofunction:: abjad.tools.pitchtools.list_named_chromatic_pitch_carriers_in_expr_sorted_by_numbered_chromatic_pitch_class.list_named_chromatic_pitch_carriers_in_expr_sorted_by_numbered_chromatic_pitch_class
